@font-face {
    font-family: Mulish;
    src: url("/static/fonts/Mulish-VariableFont_wght.ttf");
}

:root {
    --bg: #0c1016;
    --fg: #151920;
    --fg-darkened: #12161d;
    --fg-highlight: #171B22;
    --border: #555;
    --header: #fff;
    --text: #ccc;
    --text-gray: #888;
    --accent-blue: #1a2f56;
    --accent-purple: #37296a;
    --accent-green: #184212;
    --accent-dark: #111217;
}

html {
    background: var(--bg);
}

body {
    margin: 0;
}

body.contentpage {
    padding: 128px 0 40px 0;
}

* {
    /*font-family: 'Lucida Grande', 'Lucida Sans Unicode', 'Geneva', 'Verdana', sans-serif;*/
    font-family: 'Mulish', sans-serif;
}

h1,
h2,
h3,
th {
    color: var(--header);
}

p,
ul,
ol,
label,
a,
td{
    color: var(--text);
}

.logo {
    background-image: url("/static/icons/logo/white.svg");
    background-position: center;
    background-repeat: no-repeat;
    background-size: contain;
}

.topbar {
    background: var(--fg);
    padding: 14px 12px 16px 12px;
    position: fixed;
    top: 0;
    left: 0;
    width: 100vw;
    border-bottom: 1px solid var(--border);
    z-index: 100;
}

.topbar .home {
    display: block;
    width: max-content;
    text-decoration: none;
}

.topbar .home h1 {
    font-size: 40px;
    font-weight: lighter;
    margin: 0 12px 0 0;
    cursor: inherit;
}

.topbar .home h1 .logo {
    width: 45px;
    height: 45px;
    display: inline-block;
    margin: 0 12px;
    transform: translateY(8px);
    cursor: inherit;
}

.topbar .home h1 label {
    cursor: inherit;
}

.content {
    width: 90%;
    max-width: 1000px;
    background: var(--fg);
    margin: 0 auto 40px auto;
    padding: 20px 40px 40px 40px;
    border-radius: 16px;
    border: 1px solid var(--border);
}

.content .back {
    position: absolute;
    font-size: 20px;
    text-decoration: none;
    text-transform: uppercase;
}

.content .back:hover,
.content .back:focus {
    color: #fff;
}

.content .back:before {
    content: '';
    border: solid var(--text);
    border-width: 0 2px 2px 0;
    display: inline-block;
    padding: 4px;
    transform: rotate(135deg);
    -webkit-transform: rotate(135deg) translateY(3px);
}

.content .back:hover:before,
.content .back:focus:before {
    border-color: #fff;
}

.content h1,
.content h2 {
    text-align: center;
    font-weight: normal;
}

.content h1.section {
    font-size: 36px;
}

.content h2.section {
    /*make this link jumpable*/
    /*margin-top: 40px;*/
    margin-top: -110px;
    padding-top: 140px;
}

.content h2.option {
    margin-top: 40px;
    text-align: left;
    margin-bottom: 0;
}

.content p.indented {
    margin-left: 30px;
}

.content p {
    font-size: 16px;
    padding: 0;
    line-height: 24px;
}

.content p a:hover,
.content p a:focus {
    color: #fff;
}

.content th,
.content td {
    font-size: 20px;
}

input[type=text],
input[type=number] {
    color: #fff;
    background: transparent;
    outline: none;
    border-top: none;
    border-right: none;
    border-bottom: 1px solid var(--border);
    border-left: none;
    font-size: 20px;
    padding: 8px 16px;
}

input[type=number] {
    -moz-appearance: textfield;
    appearance: textfield;
}

input[type=number]::-webkit-inner-spin-button,
input[type=number]::-webkit-outer-spin-button {
    -webkit-appearance: none;
}