<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="minimal-ui, width=device-width, initial-scale=1, maximum-scale=1, user-scalable=no">

    <title>Orange Share</title>

    <link rel=stylesheet type=text/css href="/static/css/main.css">
</head>
<body class="contentpage">
    <div class="topbar">
        <a class="home" href="/">
            <h1><span class="logo"></span><label>Orange Share</label></h1>
        </a>
    </div>

    <div class="content">
        <a class="back" href="/">back</a>
        <h1>Settings</h1>
        <h2 class="section" style="color: var(--text)">Settings are not currently available in the UI. You can find a configuration file in</h2>
        <h2 class="section" style="font-weight: bold">{{conf_file}}</h2>
        <h2 class="section" style="color: var(--text)">For changes to take effect, Orange Share has to be restarted</h2>
    </div>
</body>
</html>